from setuptools import setup

setup(name='balthier_distributions',
      version='0.25',
      description='Gaussian + Binomial distributions',
      packages=['balthier_distributions'],
      zip_safe=False)
